@@ -10,6 +10,7 @@ minimal computation involved in setting the install_requires and extras_require
 arguments.
 """
 
+import argparse
 import json
 import logging
 import sys
@@ -17,7 +18,7 @@ from dataclasses import dataclass
 from functools import partial
 from operator import attrgetter
 from pathlib import Path
-from typing import List, Optional, TextIO, no_type_check
+from typing import Dict, List, Optional, TextIO, no_type_check
 
 from pydantic.json import custom_pydantic_encoder  # pylint: disable=no-name-in-module
 
@@ -33,6 +34,7 @@ from fawltydeps.settings import (
 )
 from fawltydeps.types import (
     DeclaredDependency,
+    Package,
     ParsedImport,
     UndeclaredDependency,
     UnparseablePathException,
@@ -48,6 +50,7 @@ else:
 logger = logging.getLogger(__name__)
 
 VERBOSE_PROMPT = "For a more verbose report re-run with the `--detailed` option."
+UNUSED_DEPS_OUTPUT_PREFIX = "These dependencies appear to be unused (i.e. not imported)"
 
 
 @no_type_check
@@ -68,6 +71,7 @@ class Analysis:
     settings: Settings
     imports: Optional[List[ParsedImport]] = None
     declared_deps: Optional[List[DeclaredDependency]] = None
+    resolved_deps: Optional[Dict[str, Package]] = None
     undeclared_deps: Optional[List[UndeclaredDependency]] = None
     unused_deps: Optional[List[UnusedDependency]] = None
     version: str = version()
@@ -107,7 +111,11 @@ class Analysis:
         if ret.is_enabled(Action.REPORT_UNDECLARED, Action.REPORT_UNUSED):
             assert ret.imports is not None  # convince Mypy that these cannot
             assert ret.declared_deps is not None  # be None at this time.
-            ret.undeclared_deps, ret.unused_deps = compare_imports_to_dependencies(
+            (
+                ret.resolved_deps,
+                ret.undeclared_deps,
+                ret.unused_deps,
+            ) = compare_imports_to_dependencies(
                 imports=ret.imports,
                 dependencies=ret.declared_deps,
                 settings=settings,
@@ -139,11 +147,14 @@ class Analysis:
             assert self.declared_deps is not None  # sanity-check / convince Mypy
             if details:
                 # Sort dependencies by location, then by name
-                for dep in sorted(self.declared_deps, key=attrgetter("source", "name")):
+                for dep in sorted(
+                    set(self.declared_deps), key=attrgetter("source", "name")
+                ):
                     print(f"{dep.source}: {dep.name}", file=out)
             else:
-                unique_dependencies = {i.name for i in self.declared_deps}
-                print("\n".join(sorted(unique_dependencies)), file=out)
+                print(
+                    "\n".join(sorted(set(d.name for d in self.declared_deps))), file=out
+                )
 
         if self.is_enabled(Action.REPORT_UNDECLARED) and self.undeclared_deps:
             print("\nThese imports appear to be undeclared dependencies:", file=out)
@@ -151,16 +162,13 @@ class Analysis:
                 print(f"- {undeclared.render(details)}", file=out)
 
         if self.is_enabled(Action.REPORT_UNUSED) and self.unused_deps:
-            print(
-                "\nThese dependencies appear to be unused (i.e. not imported):",
-                file=out,
-            )
-            for unused in self.unused_deps:
+            print(f"\n{UNUSED_DEPS_OUTPUT_PREFIX}:", file=out)
+            for unused in sorted(self.unused_deps, key=lambda d: d.name):
                 print(f"- {unused.render(details)}", file=out)
 
 
-def main() -> int:
-    """Command-line entry point."""
+def build_parser() -> argparse.ArgumentParser:
+    """Create the CLI parser."""
     parser, option_group = setup_cmdline_parser(description=__doc__)
     option_group.add_argument(
         "-V",
@@ -181,7 +189,12 @@ def main() -> int:
         default=False,
         help="Print a TOML config section with the current settings, and exit",
     )
+    return parser
 
+
+def main() -> int:
+    """Command-line entry point."""
+    parser = build_parser()
     args = parser.parse_args()
     settings = Settings.config(config_file=args.config_file).create(args)
 
